==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/ZestawienieWinienMa.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class ZestawienieWinienMa extends GenericDPSObject {
    /**
     * ZESTAWIENIE_WINIEN_MA.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * ZESTAWIENIE_WINIEN_MA.PRACOWNIK_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long pracownikId;

    /**
     * ZESTAWIENIE_WINIEN_MA.SZABLON_WYDRUKU_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long szablonWydrukuId;

    /**
     * ZESTAWIENIE_WINIEN_MA.DATA_GENEROWANIA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataGenerowania;

    /**
     * ZESTAWIENIE_WINIEN_MA.ROK
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Integer rok;

    /**
     * ZESTAWIENIE_WINIEN_MA.MIESIAC
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Integer miesiac;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return ZESTAWIENIE_WINIEN_MA.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * ZESTAWIENIE_WINIEN_MA.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return ZESTAWIENIE_WINIEN_MA.PRACOWNIK_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getPracownikId() {
        return pracownikId;
    }

    /**
     * ZESTAWIENIE_WINIEN_MA.PRACOWNIK_ID
     *
     * @param pracownikId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setPracownikId(Long pracownikId) {
        this.pracownikId = pracownikId;
    }

    /**
     * @return ZESTAWIENIE_WINIEN_MA.SZABLON_WYDRUKU_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getSzablonWydrukuId() {
        return szablonWydrukuId;
    }

    /**
     * ZESTAWIENIE_WINIEN_MA.SZABLON_WYDRUKU_ID
     *
     * @param szablonWydrukuId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setSzablonWydrukuId(Long szablonWydrukuId) {
        this.szablonWydrukuId = szablonWydrukuId;
    }

    /**
     * @return ZESTAWIENIE_WINIEN_MA.DATA_GENEROWANIA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataGenerowania() {
        return dataGenerowania;
    }

    /**
     * ZESTAWIENIE_WINIEN_MA.DATA_GENEROWANIA
     *
     * @param dataGenerowania
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataGenerowania(Date dataGenerowania) {
        this.dataGenerowania = dataGenerowania;
    }

    /**
     * @return ZESTAWIENIE_WINIEN_MA.ROK
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Integer getRok() {
        return rok;
    }

    /**
     * ZESTAWIENIE_WINIEN_MA.ROK
     *
     * @param rok
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setRok(Integer rok) {
        this.rok = rok;
    }

    /**
     * @return ZESTAWIENIE_WINIEN_MA.MIESIAC
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Integer getMiesiac() {
        return miesiac;
    }

    /**
     * ZESTAWIENIE_WINIEN_MA.MIESIAC
     *
     * @param miesiac
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setMiesiac(Integer miesiac) {
        this.miesiac = miesiac;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        ZestawienieWinienMa other = (ZestawienieWinienMa) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getPracownikId() == null ? other.getPracownikId() == null : this.getPracownikId().equals(other.getPracownikId()))
            && (this.getSzablonWydrukuId() == null ? other.getSzablonWydrukuId() == null : this.getSzablonWydrukuId().equals(other.getSzablonWydrukuId()))
            && (this.getDataGenerowania() == null ? other.getDataGenerowania() == null : this.getDataGenerowania().equals(other.getDataGenerowania()))
            && (this.getRok() == null ? other.getRok() == null : this.getRok().equals(other.getRok()))
            && (this.getMiesiac() == null ? other.getMiesiac() == null : this.getMiesiac().equals(other.getMiesiac()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getPracownikId() == null) ? 0 : getPracownikId().hashCode());
        result = prime * result + ((getSzablonWydrukuId() == null) ? 0 : getSzablonWydrukuId().hashCode());
        result = prime * result + ((getDataGenerowania() == null) ? 0 : getDataGenerowania().hashCode());
        result = prime * result + ((getRok() == null) ? 0 : getRok().hashCode());
        result = prime * result + ((getMiesiac() == null) ? 0 : getMiesiac().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", pracownikId=").append(pracownikId);
        sb.append(", szablonWydrukuId=").append(szablonWydrukuId);
        sb.append(", dataGenerowania=").append(dataGenerowania);
        sb.append(", rok=").append(rok);
        sb.append(", miesiac=").append(miesiac);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/ZestawienieWinienMa.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class ZestawienieWinienMa extends GenericDPSObject {
    /**
     * ZESTAWIENIE_WINIEN_MA.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * ZESTAWIENIE_WINIEN_MA.PRACOWNIK_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long pracownikId;

    /**
     * ZESTAWIENIE_WINIEN_MA.SZABLON_WYDRUKU_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long szablonWydrukuId;

    /**
     * ZESTAWIENIE_WINIEN_MA.DATA_GENEROWANIA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataGenerowania;

    /**
     * ZESTAWIENIE_WINIEN_MA.ROK
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Integer rok;

    /**
     * ZESTAWIENIE_WINIEN_MA.MIESIAC
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Integer miesiac;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return ZESTAWIENIE_WINIEN_MA.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * ZESTAWIENIE_WINIEN_MA.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return ZESTAWIENIE_WINIEN_MA.PRACOWNIK_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getPracownikId() {
        return pracownikId;
    }

    /**
     * ZESTAWIENIE_WINIEN_MA.PRACOWNIK_ID
     *
     * @param pracownikId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setPracownikId(Long pracownikId) {
        this.pracownikId = pracownikId;
    }

    /**
     * @return ZESTAWIENIE_WINIEN_MA.SZABLON_WYDRUKU_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getSzablonWydrukuId() {
        return szablonWydrukuId;
    }

    /**
     * ZESTAWIENIE_WINIEN_MA.SZABLON_WYDRUKU_ID
     *
     * @param szablonWydrukuId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setSzablonWydrukuId(Long szablonWydrukuId) {
        this.szablonWydrukuId = szablonWydrukuId;
    }

    /**
     * @return ZESTAWIENIE_WINIEN_MA.DATA_GENEROWANIA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataGenerowania() {
        return dataGenerowania;
    }

    /**
     * ZESTAWIENIE_WINIEN_MA.DATA_GENEROWANIA
     *
     * @param dataGenerowania
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataGenerowania(Date dataGenerowania) {
        this.dataGenerowania = dataGenerowania;
    }

    /**
     * @return ZESTAWIENIE_WINIEN_MA.ROK
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Integer getRok() {
        return rok;
    }

    /**
     * ZESTAWIENIE_WINIEN_MA.ROK
     *
     * @param rok
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setRok(Integer rok) {
        this.rok = rok;
    }

    /**
     * @return ZESTAWIENIE_WINIEN_MA.MIESIAC
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Integer getMiesiac() {
        return miesiac;
    }

    /**
     * ZESTAWIENIE_WINIEN_MA.MIESIAC
     *
     * @param miesiac
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setMiesiac(Integer miesiac) {
        this.miesiac = miesiac;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        ZestawienieWinienMa other = (ZestawienieWinienMa) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getPracownikId() == null ? other.getPracownikId() == null : this.getPracownikId().equals(other.getPracownikId()))
            && (this.getSzablonWydrukuId() == null ? other.getSzablonWydrukuId() == null : this.getSzablonWydrukuId().equals(other.getSzablonWydrukuId()))
            && (this.getDataGenerowania() == null ? other.getDataGenerowania() == null : this.getDataGenerowania().equals(other.getDataGenerowania()))
            && (this.getRok() == null ? other.getRok() == null : this.getRok().equals(other.getRok()))
            && (this.getMiesiac() == null ? other.getMiesiac() == null : this.getMiesiac().equals(other.getMiesiac()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getPracownikId() == null) ? 0 : getPracownikId().hashCode());
        result = prime * result + ((getSzablonWydrukuId() == null) ? 0 : getSzablonWydrukuId().hashCode());
        result = prime * result + ((getDataGenerowania() == null) ? 0 : getDataGenerowania().hashCode());
        result = prime * result + ((getRok() == null) ? 0 : getRok().hashCode());
        result = prime * result + ((getMiesiac() == null) ? 0 : getMiesiac().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", pracownikId=").append(pracownikId);
        sb.append(", szablonWydrukuId=").append(szablonWydrukuId);
        sb.append(", dataGenerowania=").append(dataGenerowania);
        sb.append(", rok=").append(rok);
        sb.append(", miesiac=").append(miesiac);
        sb.append("]");
        return sb.toString();
    }
}
